"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd2_vin_inner_script_sig import ListConfirmedTransactionsByAddressRIBSD2VinInnerScriptSig
globals()['ListConfirmedTransactionsByAddressRIBSD2VinInnerScriptSig'] = ListConfirmedTransactionsByAddressRIBSD2VinInnerScriptSig
from cryptoapis.model.list_all_unconfirmed_transactions_ribsd2_vin_inner import ListAllUnconfirmedTransactionsRIBSD2VinInner


class TestListAllUnconfirmedTransactionsRIBSD2VinInner(unittest.TestCase):
    """ListAllUnconfirmedTransactionsRIBSD2VinInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllUnconfirmedTransactionsRIBSD2VinInner(self):
        """Test ListAllUnconfirmedTransactionsRIBSD2VinInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllUnconfirmedTransactionsRIBSD2VinInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsb import GetBlockDetailsByBlockHeightFromCallbackRIBSB
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsbc import GetBlockDetailsByBlockHeightFromCallbackRIBSBC
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsbsc import GetBlockDetailsByBlockHeightFromCallbackRIBSBSC
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsd import GetBlockDetailsByBlockHeightFromCallbackRIBSD
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsd2 import GetBlockDetailsByBlockHeightFromCallbackRIBSD2
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribse import GetBlockDetailsByBlockHeightFromCallbackRIBSE
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsec import GetBlockDetailsByBlockHeightFromCallbackRIBSEC
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsl import GetBlockDetailsByBlockHeightFromCallbackRIBSL
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsx import GetBlockDetailsByBlockHeightFromCallbackRIBSX
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsz import GetBlockDetailsByBlockHeightFromCallbackRIBSZ
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsz2 import GetBlockDetailsByBlockHeightFromCallbackRIBSZ2
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_coins import GetLatestMinedXRPRippleBlockRITotalCoins
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_fees import GetLatestMinedXRPRippleBlockRITotalFees
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSB'] = GetBlockDetailsByBlockHeightFromCallbackRIBSB
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSBC'] = GetBlockDetailsByBlockHeightFromCallbackRIBSBC
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSBSC'] = GetBlockDetailsByBlockHeightFromCallbackRIBSBSC
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSD'] = GetBlockDetailsByBlockHeightFromCallbackRIBSD
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSD2'] = GetBlockDetailsByBlockHeightFromCallbackRIBSD2
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSE'] = GetBlockDetailsByBlockHeightFromCallbackRIBSE
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSEC'] = GetBlockDetailsByBlockHeightFromCallbackRIBSEC
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSL'] = GetBlockDetailsByBlockHeightFromCallbackRIBSL
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSX'] = GetBlockDetailsByBlockHeightFromCallbackRIBSX
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSZ'] = GetBlockDetailsByBlockHeightFromCallbackRIBSZ
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSZ2'] = GetBlockDetailsByBlockHeightFromCallbackRIBSZ2
globals()['GetLatestMinedXRPRippleBlockRITotalCoins'] = GetLatestMinedXRPRippleBlockRITotalCoins
globals()['GetLatestMinedXRPRippleBlockRITotalFees'] = GetLatestMinedXRPRippleBlockRITotalFees
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribs import GetBlockDetailsByBlockHeightFromCallbackRIBS


class TestGetBlockDetailsByBlockHeightFromCallbackRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHeightFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHeightFromCallbackRIBS(self):
        """Test GetBlockDetailsByBlockHeightFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHeightFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_blockchain_events_subscriptions_ri_deactivation_reasons_inner import ListBlockchainEventsSubscriptionsRIDeactivationReasonsInner


class TestListBlockchainEventsSubscriptionsRIDeactivationReasonsInner(unittest.TestCase):
    """ListBlockchainEventsSubscriptionsRIDeactivationReasonsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListBlockchainEventsSubscriptionsRIDeactivationReasonsInner(self):
        """Test ListBlockchainEventsSubscriptionsRIDeactivationReasonsInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListBlockchainEventsSubscriptionsRIDeactivationReasonsInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_data_item_mined_in_block import AddressTokensTransactionConfirmedDataItemMinedInBlock
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_token import ConfirmedTokensTransactionForCertainAmountOrHigherToken
globals()['AddressTokensTransactionConfirmedDataItemMinedInBlock'] = AddressTokensTransactionConfirmedDataItemMinedInBlock
globals()['ConfirmedTokensTransactionForCertainAmountOrHigherToken'] = ConfirmedTokensTransactionForCertainAmountOrHigherToken
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_data_item import ConfirmedTokensTransactionForCertainAmountOrHigherDataItem


class TestConfirmedTokensTransactionForCertainAmountOrHigherDataItem(unittest.TestCase):
    """ConfirmedTokensTransactionForCertainAmountOrHigherDataItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConfirmedTokensTransactionForCertainAmountOrHigherDataItem(self):
        """Test ConfirmedTokensTransactionForCertainAmountOrHigherDataItem"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConfirmedTokensTransactionForCertainAmountOrHigherDataItem()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.informative_api import InformativeApi  # noqa: E501


class TestInformativeApi(unittest.TestCase):
    """InformativeApi unit test stubs"""

    def setUp(self):
        self.api = InformativeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transaction_request_details(self):
        """Test case for get_transaction_request_details

        Get Transaction Request Details  # noqa: E501
        """
        pass

    def test_get_wallet_asset_details(self):
        """Test case for get_wallet_asset_details

        Get Wallet Asset Details  # noqa: E501
        """
        pass

    def test_get_wallet_transaction_details_by_transaction_id(self):
        """Test case for get_wallet_transaction_details_by_transaction_id

        Get Wallet Transaction Details By Transaction ID  # noqa: E501
        """
        pass

    def test_list_all_assets_by_wallet_id(self):
        """Test case for list_all_assets_by_wallet_id

        List All Assets By Wallet ID  # noqa: E501
        """
        pass

    def test_list_all_assets_from_all_wallets(self):
        """Test case for list_all_assets_from_all_wallets

        List All Assets From All Wallets  # noqa: E501
        """
        pass

    def test_list_deposit_addresses(self):
        """Test case for list_deposit_addresses

        List Deposit Addresses  # noqa: E501
        """
        pass

    def test_list_supported_tokens(self):
        """Test case for list_supported_tokens

        List Supported Tokens  # noqa: E501
        """
        pass

    def test_list_wallet_transactions(self):
        """Test case for list_wallet_transactions

        List Wallet Transactions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount400_response import CreateCoinsTransactionFromAddressForWholeAmount400Response
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount401_response import CreateCoinsTransactionFromAddressForWholeAmount401Response
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount403_response import CreateCoinsTransactionFromAddressForWholeAmount403Response
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount409_response import CreateCoinsTransactionFromAddressForWholeAmount409Response
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount_r import CreateCoinsTransactionFromAddressForWholeAmountR
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount_rb import CreateCoinsTransactionFromAddressForWholeAmountRB
from cryptoapis.model.create_coins_transaction_request_from_address400_response import CreateCoinsTransactionRequestFromAddress400Response
from cryptoapis.model.create_coins_transaction_request_from_address401_response import CreateCoinsTransactionRequestFromAddress401Response
from cryptoapis.model.create_coins_transaction_request_from_address403_response import CreateCoinsTransactionRequestFromAddress403Response
from cryptoapis.model.create_coins_transaction_request_from_address409_response import CreateCoinsTransactionRequestFromAddress409Response
from cryptoapis.model.create_coins_transaction_request_from_address_r import CreateCoinsTransactionRequestFromAddressR
from cryptoapis.model.create_coins_transaction_request_from_address_rb import CreateCoinsTransactionRequestFromAddressRB
from cryptoapis.model.create_coins_transaction_request_from_wallet400_response import CreateCoinsTransactionRequestFromWallet400Response
from cryptoapis.model.create_coins_transaction_request_from_wallet401_response import CreateCoinsTransactionRequestFromWallet401Response
from cryptoapis.model.create_coins_transaction_request_from_wallet403_response import CreateCoinsTransactionRequestFromWallet403Response
from cryptoapis.model.create_coins_transaction_request_from_wallet409_response import CreateCoinsTransactionRequestFromWallet409Response
from cryptoapis.model.create_coins_transaction_request_from_wallet_r import CreateCoinsTransactionRequestFromWalletR
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb import CreateCoinsTransactionRequestFromWalletRB
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address400_response import CreateFungibleTokensTransactionRequestFromAddress400Response
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address401_response import CreateFungibleTokensTransactionRequestFromAddress401Response
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address403_response import CreateFungibleTokensTransactionRequestFromAddress403Response
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address409_response import CreateFungibleTokensTransactionRequestFromAddress409Response
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address_r import CreateFungibleTokensTransactionRequestFromAddressR
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address_rb import CreateFungibleTokensTransactionRequestFromAddressRB
from cryptoapis.model.get_address_details402_response import GetAddressDetails402Response
from cryptoapis.model.get_address_details415_response import GetAddressDetails415Response
from cryptoapis.model.get_address_details422_response import GetAddressDetails422Response
from cryptoapis.model.get_address_details429_response import GetAddressDetails429Response
from cryptoapis.model.get_address_details500_response import GetAddressDetails500Response


class TransactionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_coins_transaction_from_address_for_whole_amount_endpoint = _Endpoint(
            settings={
                'response_type': (CreateCoinsTransactionFromAddressForWholeAmountR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{address}/all-transaction-requests',
                'operation_id': 'create_coins_transaction_from_address_for_whole_amount',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'create_coins_transaction_from_address_for_whole_amount_rb',
                ],
                'required': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'address':
                        (str,),
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_coins_transaction_from_address_for_whole_amount_rb':
                        (CreateCoinsTransactionFromAddressForWholeAmountRB,),
                },
                'attribute_map': {
                    'address': 'address',
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'address': 'path',
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_coins_transaction_from_address_for_whole_amount_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_coins_transaction_request_from_address_endpoint = _Endpoint(
            settings={
                'response_type': (CreateCoinsTransactionRequestFromAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{address}/transaction-requests',
                'operation_id': 'create_coins_transaction_request_from_address',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'create_coins_transaction_request_from_address_rb',
                ],
                'required': [
                    'address',
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "XRP": "xrp"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'address':
                        (str,),
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_coins_transaction_request_from_address_rb':
                        (CreateCoinsTransactionRequestFromAddressRB,),
                },
                'attribute_map': {
                    'address': 'address',
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'address': 'path',
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_coins_transaction_request_from_address_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_coins_transaction_request_from_wallet_endpoint = _Endpoint(
            settings={
                'response_type': (CreateCoinsTransactionRequestFromWalletR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/transaction-requests',
                'operation_id': 'create_coins_transaction_request_from_wallet',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'create_coins_transaction_request_from_wallet_rb',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ZCASH": "zcash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_coins_transaction_request_from_wallet_rb':
                        (CreateCoinsTransactionRequestFromWalletRB,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_coins_transaction_request_from_wallet_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_fungible_tokens_transaction_request_from_address_endpoint = _Endpoint(
            settings={
                'response_type': (CreateFungibleTokensTransactionRequestFromAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{senderAddress}/token-transaction-requests',
                'operation_id': 'create_fungible_tokens_transaction_request_from_address',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'sender_address',
                    'wallet_id',
                    'context',
                    'create_fungible_tokens_transaction_request_from_address_rb',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'sender_address',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor",
                        "TESTNET": "testnet"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'sender_address':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'create_fungible_tokens_transaction_request_from_address_rb':
                        (CreateFungibleTokensTransactionRequestFromAddressRB,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'sender_address': 'senderAddress',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'sender_address': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'create_fungible_tokens_transaction_request_from_address_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_coins_transaction_from_address_for_whole_amount(
        self,
        address,
        blockchain,
        network,
        wallet_id,
        **kwargs
    ):
        """Create Coins Transaction From Address For Whole Amount  # noqa: E501

        Through this endpoint customers can create a new transaction from address for **coins** specifically, which will transfer over the entire available amount.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_coins_transaction_from_address_for_whole_amount(address, blockchain, network, wallet_id, async_req=True)
        >>> result = thread.get()

        Args:
            address (str): Defines the source address.
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            wallet_id (str): Represents the sender's specific and unique Wallet ID of the sender.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            create_coins_transaction_from_address_for_whole_amount_rb (CreateCoinsTransactionFromAddressForWholeAmountRB): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateCoinsTransactionFromAddressForWholeAmountR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['address'] = \
            address
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['wallet_id'] = \
            wallet_id
        return self.create_coins_transaction_from_address_for_whole_amount_endpoint.call_with_http_info(**kwargs)

    def create_coins_transaction_request_from_address(
        self,
        address,
        blockchain,
        network,
        wallet_id,
        **kwargs
    ):
        """Create Coins Transaction Request from Address  # noqa: E501

        Through this endpoint users can create a new single transaction request from one address to another.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_coins_transaction_request_from_address(address, blockchain, network, wallet_id, async_req=True)
        >>> result = thread.get()

        Args:
            address (str): Defines the specific source address for the transaction. For XRP we also support the X-address format.
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            wallet_id (str): Represents the sender's specific and unique Wallet ID of the sender.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            create_coins_transaction_request_from_address_rb (CreateCoinsTransactionRequestFromAddressRB): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateCoinsTransactionRequestFromAddressR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['address'] = \
            address
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['wallet_id'] = \
            wallet_id
        return self.create_coins_transaction_request_from_address_endpoint.call_with_http_info(**kwargs)

    def create_coins_transaction_request_from_wallet(
        self,
        blockchain,
        wallet_id,
        network="testnet",
        **kwargs
    ):
        """Create Coins Transaction Request from Wallet  # noqa: E501

        Through this endpoint users can create a new transaction request from the entire Wallet instead from just a specific address. This endpoint can generate transactions from multiple to multiple addresses.    {warning}This is available **only** for UTXO-based protocols such as Bitcoin, Bitcoin Cash, Litecoin, etc. It **is not** available for Account-based protocols like Ethereum.{/warning}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_coins_transaction_request_from_wallet(blockchain, wallet_id, network="testnet", async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            wallet_id (str): Represents the sender's specific and unique Wallet ID of the sender.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.. defaults to "testnet", must be one of ["testnet"]

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            create_coins_transaction_request_from_wallet_rb (CreateCoinsTransactionRequestFromWalletRB): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateCoinsTransactionRequestFromWalletR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['wallet_id'] = \
            wallet_id
        return self.create_coins_transaction_request_from_wallet_endpoint.call_with_http_info(**kwargs)

    def create_fungible_tokens_transaction_request_from_address(
        self,
        sender_address,
        wallet_id,
        blockchain="ethereum",
        network="mainnet",
        **kwargs
    ):
        """Create Fungible Tokens Transaction Request from Address  # noqa: E501

        Through this endpoint users can make a single token transaction.    {note}To have an operational callback subscription, you need to first verify a domain for the Callback URL. Please see more information on Callbacks [here](https://developers.cryptoapis.io/technical-documentation/general-information/callbacks#callback-url).{/note}    {warning}Crypto APIs will notify the user **only when** the event occurs. There are cases when the specific event doesn't happen at all, or takes a long time to do so. A callback notification **will not** be sent if the event does not or cannot occur, or will take long time to occur.{/warning}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_fungible_tokens_transaction_request_from_address(sender_address, wallet_id, blockchain="ethereum", network="mainnet", async_req=True)
        >>> result = thread.get()

        Args:
            sender_address (str): Defines the specific source address for the transaction.
            wallet_id (str): Defines the unique ID of the Wallet.
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.. defaults to "ethereum", must be one of ["ethereum"]
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.. defaults to "mainnet", must be one of ["mainnet"]

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            create_fungible_tokens_transaction_request_from_address_rb (CreateFungibleTokensTransactionRequestFromAddressRB): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateFungibleTokensTransactionRequestFromAddressR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['sender_address'] = \
            sender_address
        kwargs['wallet_id'] = \
            wallet_id
        return self.create_fungible_tokens_transaction_request_from_address_endpoint.call_with_http_info(**kwargs)




"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.manage_subscriptions_api import ManageSubscriptionsApi  # noqa: E501


class TestManageSubscriptionsApi(unittest.TestCase):
    """ManageSubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = ManageSubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_blockchain_event_subscription(self):
        """Test case for activate_blockchain_event_subscription

        Activate Blockchain Event Subscription  # noqa: E501
        """
        pass

    def test_delete_blockchain_event_subscription(self):
        """Test case for delete_blockchain_event_subscription

        Delete Blockchain Event Subscription  # noqa: E501
        """
        pass

    def test_get_blockchain_event_subscription_details_by_reference_id(self):
        """Test case for get_blockchain_event_subscription_details_by_reference_id

        Get Blockchain Event Subscription Details By Reference ID  # noqa: E501
        """
        pass

    def test_list_blockchain_events_subscriptions(self):
        """Test case for list_blockchain_events_subscriptions

        List Blockchain Events Subscriptions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.derive_hd_wallet_x_pub_y_pub_z_pub_change_or_receiving_addresses_e403 import DeriveHDWalletXPubYPubZPubChangeOrReceivingAddressesE403
globals()['DeriveHDWalletXPubYPubZPubChangeOrReceivingAddressesE403'] = DeriveHDWalletXPubYPubZPubChangeOrReceivingAddressesE403
from cryptoapis.model.derive_hd_wallet_x_pub_y_pub_z_pub_change_or_receiving_addresses403_response import DeriveHDWalletXPubYPubZPubChangeOrReceivingAddresses403Response


class TestDeriveHDWalletXPubYPubZPubChangeOrReceivingAddresses403Response(unittest.TestCase):
    """DeriveHDWalletXPubYPubZPubChangeOrReceivingAddresses403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeriveHDWalletXPubYPubZPubChangeOrReceivingAddresses403Response(self):
        """Test DeriveHDWalletXPubYPubZPubChangeOrReceivingAddresses403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeriveHDWalletXPubYPubZPubChangeOrReceivingAddresses403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
from cryptoapis.model.list_all_unconfirmed_transactions_ribsz import ListAllUnconfirmedTransactionsRIBSZ


class TestListAllUnconfirmedTransactionsRIBSZ(unittest.TestCase):
    """ListAllUnconfirmedTransactionsRIBSZ unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllUnconfirmedTransactionsRIBSZ(self):
        """Test ListAllUnconfirmedTransactionsRIBSZ"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllUnconfirmedTransactionsRIBSZ()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_eip1559_fee_recommendations_ri_base_fee_per_gas import GetEIP1559FeeRecommendationsRIBaseFeePerGas
from cryptoapis.model.get_eip1559_fee_recommendations_ri_max_fee_per_gas import GetEIP1559FeeRecommendationsRIMaxFeePerGas
from cryptoapis.model.get_eip1559_fee_recommendations_ri_max_priority_fee_per_gas import GetEIP1559FeeRecommendationsRIMaxPriorityFeePerGas
globals()['GetEIP1559FeeRecommendationsRIBaseFeePerGas'] = GetEIP1559FeeRecommendationsRIBaseFeePerGas
globals()['GetEIP1559FeeRecommendationsRIMaxFeePerGas'] = GetEIP1559FeeRecommendationsRIMaxFeePerGas
globals()['GetEIP1559FeeRecommendationsRIMaxPriorityFeePerGas'] = GetEIP1559FeeRecommendationsRIMaxPriorityFeePerGas
from cryptoapis.model.get_eip1559_fee_recommendations_ri import GetEIP1559FeeRecommendationsRI


class TestGetEIP1559FeeRecommendationsRI(unittest.TestCase):
    """GetEIP1559FeeRecommendationsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetEIP1559FeeRecommendationsRI(self):
        """Test GetEIP1559FeeRecommendationsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetEIP1559FeeRecommendationsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_all_assets_from_all_wallets_ri_coins_inner import ListAllAssetsFromAllWalletsRICoinsInner
from cryptoapis.model.list_all_assets_from_all_wallets_ri_fungible_tokens_inner import ListAllAssetsFromAllWalletsRIFungibleTokensInner
from cryptoapis.model.list_all_assets_from_all_wallets_ri_non_fungible_tokens_inner import ListAllAssetsFromAllWalletsRINonFungibleTokensInner
globals()['ListAllAssetsFromAllWalletsRICoinsInner'] = ListAllAssetsFromAllWalletsRICoinsInner
globals()['ListAllAssetsFromAllWalletsRIFungibleTokensInner'] = ListAllAssetsFromAllWalletsRIFungibleTokensInner
globals()['ListAllAssetsFromAllWalletsRINonFungibleTokensInner'] = ListAllAssetsFromAllWalletsRINonFungibleTokensInner
from cryptoapis.model.list_all_assets_from_all_wallets_ri import ListAllAssetsFromAllWalletsRI


class TestListAllAssetsFromAllWalletsRI(unittest.TestCase):
    """ListAllAssetsFromAllWalletsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllAssetsFromAllWalletsRI(self):
        """Test ListAllAssetsFromAllWalletsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllAssetsFromAllWalletsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsb import ListUnconfirmedTransactionsByAddressRIBSB
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsbc import ListUnconfirmedTransactionsByAddressRIBSBC
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsbsc import ListUnconfirmedTransactionsByAddressRIBSBSC
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd import ListUnconfirmedTransactionsByAddressRIBSD
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2 import ListUnconfirmedTransactionsByAddressRIBSD2
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribse import ListUnconfirmedTransactionsByAddressRIBSE
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsec import ListUnconfirmedTransactionsByAddressRIBSEC
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsec_fee import ListUnconfirmedTransactionsByAddressRIBSECFee
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsl import ListUnconfirmedTransactionsByAddressRIBSL
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsz import ListUnconfirmedTransactionsByAddressRIBSZ
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['ListUnconfirmedTransactionsByAddressRIBSB'] = ListUnconfirmedTransactionsByAddressRIBSB
globals()['ListUnconfirmedTransactionsByAddressRIBSBC'] = ListUnconfirmedTransactionsByAddressRIBSBC
globals()['ListUnconfirmedTransactionsByAddressRIBSBSC'] = ListUnconfirmedTransactionsByAddressRIBSBSC
globals()['ListUnconfirmedTransactionsByAddressRIBSD'] = ListUnconfirmedTransactionsByAddressRIBSD
globals()['ListUnconfirmedTransactionsByAddressRIBSD2'] = ListUnconfirmedTransactionsByAddressRIBSD2
globals()['ListUnconfirmedTransactionsByAddressRIBSE'] = ListUnconfirmedTransactionsByAddressRIBSE
globals()['ListUnconfirmedTransactionsByAddressRIBSEC'] = ListUnconfirmedTransactionsByAddressRIBSEC
globals()['ListUnconfirmedTransactionsByAddressRIBSECFee'] = ListUnconfirmedTransactionsByAddressRIBSECFee
globals()['ListUnconfirmedTransactionsByAddressRIBSL'] = ListUnconfirmedTransactionsByAddressRIBSL
globals()['ListUnconfirmedTransactionsByAddressRIBSZ'] = ListUnconfirmedTransactionsByAddressRIBSZ
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribs import ListUnconfirmedTransactionsByAddressRIBS


class TestListUnconfirmedTransactionsByAddressRIBS(unittest.TestCase):
    """ListUnconfirmedTransactionsByAddressRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListUnconfirmedTransactionsByAddressRIBS(self):
        """Test ListUnconfirmedTransactionsByAddressRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListUnconfirmedTransactionsByAddressRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.activate_blockchain_event_subscription_e400 import ActivateBlockchainEventSubscriptionE400
globals()['ActivateBlockchainEventSubscriptionE400'] = ActivateBlockchainEventSubscriptionE400
from cryptoapis.model.activate_blockchain_event_subscription400_response import ActivateBlockchainEventSubscription400Response


class TestActivateBlockchainEventSubscription400Response(unittest.TestCase):
    """ActivateBlockchainEventSubscription400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testActivateBlockchainEventSubscription400Response(self):
        """Test ActivateBlockchainEventSubscription400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ActivateBlockchainEventSubscription400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsb import GetBlockDetailsByBlockHashFromCallbackRIBSB
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsbc import GetBlockDetailsByBlockHashFromCallbackRIBSBC
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsbsc import GetBlockDetailsByBlockHashFromCallbackRIBSBSC
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsd import GetBlockDetailsByBlockHashFromCallbackRIBSD
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsd2 import GetBlockDetailsByBlockHashFromCallbackRIBSD2
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribse import GetBlockDetailsByBlockHashFromCallbackRIBSE
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsec import GetBlockDetailsByBlockHashFromCallbackRIBSEC
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsl import GetBlockDetailsByBlockHashFromCallbackRIBSL
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsx import GetBlockDetailsByBlockHashFromCallbackRIBSX
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsz import GetBlockDetailsByBlockHashFromCallbackRIBSZ
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsz2 import GetBlockDetailsByBlockHashFromCallbackRIBSZ2
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_coins import GetLatestMinedXRPRippleBlockRITotalCoins
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_fees import GetLatestMinedXRPRippleBlockRITotalFees
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSB'] = GetBlockDetailsByBlockHashFromCallbackRIBSB
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSBC'] = GetBlockDetailsByBlockHashFromCallbackRIBSBC
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSBSC'] = GetBlockDetailsByBlockHashFromCallbackRIBSBSC
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSD'] = GetBlockDetailsByBlockHashFromCallbackRIBSD
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSD2'] = GetBlockDetailsByBlockHashFromCallbackRIBSD2
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSE'] = GetBlockDetailsByBlockHashFromCallbackRIBSE
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSEC'] = GetBlockDetailsByBlockHashFromCallbackRIBSEC
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSL'] = GetBlockDetailsByBlockHashFromCallbackRIBSL
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSX'] = GetBlockDetailsByBlockHashFromCallbackRIBSX
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSZ'] = GetBlockDetailsByBlockHashFromCallbackRIBSZ
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSZ2'] = GetBlockDetailsByBlockHashFromCallbackRIBSZ2
globals()['GetLatestMinedXRPRippleBlockRITotalCoins'] = GetLatestMinedXRPRippleBlockRITotalCoins
globals()['GetLatestMinedXRPRippleBlockRITotalFees'] = GetLatestMinedXRPRippleBlockRITotalFees
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribs import GetBlockDetailsByBlockHashFromCallbackRIBS


class TestGetBlockDetailsByBlockHashFromCallbackRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHashFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHashFromCallbackRIBS(self):
        """Test GetBlockDetailsByBlockHashFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHashFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash_e403 import GetXRPRippleBlockDetailsByBlockHashE403
globals()['GetXRPRippleBlockDetailsByBlockHashE403'] = GetXRPRippleBlockDetailsByBlockHashE403
from cryptoapis.model.get_xrp_ripple_block_details_by_block_hash403_response import GetXRPRippleBlockDetailsByBlockHash403Response


class TestGetXRPRippleBlockDetailsByBlockHash403Response(unittest.TestCase):
    """GetXRPRippleBlockDetailsByBlockHash403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetXRPRippleBlockDetailsByBlockHash403Response(self):
        """Test GetXRPRippleBlockDetailsByBlockHash403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetXRPRippleBlockDetailsByBlockHash403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_address_details_from_callback_e401 import GetAddressDetailsFromCallbackE401
globals()['GetAddressDetailsFromCallbackE401'] = GetAddressDetailsFromCallbackE401
from cryptoapis.model.get_address_details_from_callback401_response import GetAddressDetailsFromCallback401Response


class TestGetAddressDetailsFromCallback401Response(unittest.TestCase):
    """GetAddressDetailsFromCallback401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetAddressDetailsFromCallback401Response(self):
        """Test GetAddressDetailsFromCallback401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetAddressDetailsFromCallback401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_recipients_inner import GetXRPRippleTransactionDetailsByTransactionIDRIRecipientsInner
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_senders_inner import GetXRPRippleTransactionDetailsByTransactionIDRISendersInner
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_fee import ListXRPRippleTransactionsByAddressRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_offer import ListXRPRippleTransactionsByAddressRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_receive import ListXRPRippleTransactionsByAddressRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_value import ListXRPRippleTransactionsByAddressRIValue
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIRecipientsInner'] = GetXRPRippleTransactionDetailsByTransactionIDRIRecipientsInner
globals()['GetXRPRippleTransactionDetailsByTransactionIDRISendersInner'] = GetXRPRippleTransactionDetailsByTransactionIDRISendersInner
globals()['ListXRPRippleTransactionsByAddressRIFee'] = ListXRPRippleTransactionsByAddressRIFee
globals()['ListXRPRippleTransactionsByAddressRIOffer'] = ListXRPRippleTransactionsByAddressRIOffer
globals()['ListXRPRippleTransactionsByAddressRIReceive'] = ListXRPRippleTransactionsByAddressRIReceive
globals()['ListXRPRippleTransactionsByAddressRIValue'] = ListXRPRippleTransactionsByAddressRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_address_and_time_range_ri import ListXRPRippleTransactionsByAddressAndTimeRangeRI


class TestListXRPRippleTransactionsByAddressAndTimeRangeRI(unittest.TestCase):
    """ListXRPRippleTransactionsByAddressAndTimeRangeRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByAddressAndTimeRangeRI(self):
        """Test ListXRPRippleTransactionsByAddressAndTimeRangeRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByAddressAndTimeRangeRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_height_ribsl_vin_inner import ListTransactionsByBlockHeightRIBSLVinInner
from cryptoapis.model.list_transactions_by_block_height_ribsl_vout_inner import ListTransactionsByBlockHeightRIBSLVoutInner
globals()['ListTransactionsByBlockHeightRIBSLVinInner'] = ListTransactionsByBlockHeightRIBSLVinInner
globals()['ListTransactionsByBlockHeightRIBSLVoutInner'] = ListTransactionsByBlockHeightRIBSLVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribsl import ListTransactionsByBlockHeightRIBSL


class TestListTransactionsByBlockHeightRIBSL(unittest.TestCase):
    """ListTransactionsByBlockHeightRIBSL unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHeightRIBSL(self):
        """Test ListTransactionsByBlockHeightRIBSL"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHeightRIBSL()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_height_e400 import GetBlockDetailsByBlockHeightE400
globals()['GetBlockDetailsByBlockHeightE400'] = GetBlockDetailsByBlockHeightE400
from cryptoapis.model.get_block_details_by_block_height400_response import GetBlockDetailsByBlockHeight400Response


class TestGetBlockDetailsByBlockHeight400Response(unittest.TestCase):
    """GetBlockDetailsByBlockHeight400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHeight400Response(self):
        """Test GetBlockDetailsByBlockHeight400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHeight400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.generate_deposit_address400_response import GenerateDepositAddress400Response
from cryptoapis.model.generate_deposit_address401_response import GenerateDepositAddress401Response
from cryptoapis.model.generate_deposit_address403_response import GenerateDepositAddress403Response
from cryptoapis.model.generate_deposit_address_r import GenerateDepositAddressR
from cryptoapis.model.generate_deposit_address_rb import GenerateDepositAddressRB
from cryptoapis.model.get_address_details402_response import GetAddressDetails402Response
from cryptoapis.model.get_address_details409_response import GetAddressDetails409Response
from cryptoapis.model.get_address_details415_response import GetAddressDetails415Response
from cryptoapis.model.get_address_details422_response import GetAddressDetails422Response
from cryptoapis.model.get_address_details429_response import GetAddressDetails429Response
from cryptoapis.model.get_address_details500_response import GetAddressDetails500Response
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_id404_response import GetXRPRippleTransactionDetailsByTransactionID404Response


class GeneratingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.generate_deposit_address_endpoint = _Endpoint(
            settings={
                'response_type': (GenerateDepositAddressR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses',
                'operation_id': 'generate_deposit_address',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'wallet_id',
                    'context',
                    'generate_deposit_address_rb',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'wallet_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "XRP": "xrp",
                        "ZCASH": "zcash",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'wallet_id':
                        (str,),
                    'context':
                        (str,),
                    'generate_deposit_address_rb':
                        (GenerateDepositAddressRB,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'wallet_id': 'walletId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'wallet_id': 'path',
                    'context': 'query',
                    'generate_deposit_address_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def generate_deposit_address(
        self,
        blockchain,
        network,
        wallet_id,
        **kwargs
    ):
        """Generate Deposit Address  # noqa: E501

        Through this endpoint customers can generate a new Receiving/Deposit Addresses into their Wallet.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_deposit_address(blockchain, network, wallet_id, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            wallet_id (str): Represents the unique ID of the specific Wallet.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            generate_deposit_address_rb (GenerateDepositAddressRB): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GenerateDepositAddressR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['wallet_id'] = \
            wallet_id
        return self.generate_deposit_address_endpoint.call_with_http_info(**kwargs)




"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vin_inner import GetTransactionDetailsByTransactionIDRIBSD2VinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vout_inner import GetTransactionDetailsByTransactionIDRIBSD2VoutInner
globals()['GetTransactionDetailsByTransactionIDRIBSD2VinInner'] = GetTransactionDetailsByTransactionIDRIBSD2VinInner
globals()['GetTransactionDetailsByTransactionIDRIBSD2VoutInner'] = GetTransactionDetailsByTransactionIDRIBSD2VoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2 import GetTransactionDetailsByTransactionIDRIBSD2


class TestGetTransactionDetailsByTransactionIDRIBSD2(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDRIBSD2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDRIBSD2(self):
        """Test GetTransactionDetailsByTransactionIDRIBSD2"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDRIBSD2()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.new_confirmed_token_transactions_for_specific_amount_e403 import NewConfirmedTokenTransactionsForSpecificAmountE403
globals()['NewConfirmedTokenTransactionsForSpecificAmountE403'] = NewConfirmedTokenTransactionsForSpecificAmountE403
from cryptoapis.model.new_confirmed_token_transactions_for_specific_amount403_response import NewConfirmedTokenTransactionsForSpecificAmount403Response


class TestNewConfirmedTokenTransactionsForSpecificAmount403Response(unittest.TestCase):
    """NewConfirmedTokenTransactionsForSpecificAmount403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewConfirmedTokenTransactionsForSpecificAmount403Response(self):
        """Test NewConfirmedTokenTransactionsForSpecificAmount403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NewConfirmedTokenTransactionsForSpecificAmount403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.xrp_ripple_api import XRPRippleApi  # noqa: E501


class TestXRPRippleApi(unittest.TestCase):
    """XRPRippleApi unit test stubs"""

    def setUp(self):
        self.api = XRPRippleApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_latest_mined_xrp__ripple_block(self):
        """Test case for get_latest_mined_xrp__ripple_block

        Get Latest Mined XRP (Ripple) Block  # noqa: E501
        """
        pass

    def test_get_xrp__ripple_address_details(self):
        """Test case for get_xrp__ripple_address_details

        Get XRP (Ripple) Address Details  # noqa: E501
        """
        pass

    def test_get_xrp__ripple_block_details_by_block_hash(self):
        """Test case for get_xrp__ripple_block_details_by_block_hash

        Get XRP (Ripple) Block Details By Block Hash  # noqa: E501
        """
        pass

    def test_get_xrp__ripple_block_details_by_block_height(self):
        """Test case for get_xrp__ripple_block_details_by_block_height

        Get XRP (Ripple) Block Details By Block Height  # noqa: E501
        """
        pass

    def test_get_xrp__ripple_transaction_details_by_transaction_id(self):
        """Test case for get_xrp__ripple_transaction_details_by_transaction_id

        Get XRP (Ripple) Transaction Details By Transaction ID  # noqa: E501
        """
        pass

    def test_list_xrp__ripple_transactions_by_address(self):
        """Test case for list_xrp__ripple_transactions_by_address

        List XRP (Ripple) Transactions by Address  # noqa: E501
        """
        pass

    def test_list_xrp__ripple_transactions_by_address_and_time_range(self):
        """Test case for list_xrp__ripple_transactions_by_address_and_time_range

        List XRP (Ripple) Transactions By Address And Time Range  # noqa: E501
        """
        pass

    def test_list_xrp__ripple_transactions_by_block_hash(self):
        """Test case for list_xrp__ripple_transactions_by_block_hash

        List XRP (Ripple) Transactions By Block Hash  # noqa: E501
        """
        pass

    def test_list_xrp__ripple_transactions_by_block_height(self):
        """Test case for list_xrp__ripple_transactions_by_block_height

        List XRP (Ripple) Transactions By Block Height  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsb import GetTransactionDetailsByTransactionIDFromCallbackRIBSB
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsbc import GetTransactionDetailsByTransactionIDFromCallbackRIBSBC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsbsc import GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsd import GetTransactionDetailsByTransactionIDFromCallbackRIBSD
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsd2 import GetTransactionDetailsByTransactionIDFromCallbackRIBSD2
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribse import GetTransactionDetailsByTransactionIDFromCallbackRIBSE
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsec import GetTransactionDetailsByTransactionIDFromCallbackRIBSEC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsl import GetTransactionDetailsByTransactionIDFromCallbackRIBSL
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsx import GetTransactionDetailsByTransactionIDFromCallbackRIBSX
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsx_value import GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz2 import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz2_gas_price import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2GasPrice
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_offer import GetXRPRippleTransactionDetailsByTransactionIDRIOffer
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_receive import GetXRPRippleTransactionDetailsByTransactionIDRIReceive
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSB'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSB
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSBC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSBC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSD'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSD
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSD2'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSD2
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSE'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSE
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSEC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSEC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSL'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSL
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSX'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSX
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2GasPrice'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2GasPrice
globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIOffer'] = GetXRPRippleTransactionDetailsByTransactionIDRIOffer
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIReceive'] = GetXRPRippleTransactionDetailsByTransactionIDRIReceive
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribs import GetTransactionDetailsByTransactionIDFromCallbackRIBS


class TestGetTransactionDetailsByTransactionIDFromCallbackRIBS(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDFromCallbackRIBS(self):
        """Test GetTransactionDetailsByTransactionIDFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_address_details_from_callback_ri_total_received import GetAddressDetailsFromCallbackRITotalReceived
from cryptoapis.model.get_address_details_from_callback_ri_total_spent import GetAddressDetailsFromCallbackRITotalSpent
from cryptoapis.model.get_address_details_ri_confirmed_balance import GetAddressDetailsRIConfirmedBalance
globals()['GetAddressDetailsFromCallbackRITotalReceived'] = GetAddressDetailsFromCallbackRITotalReceived
globals()['GetAddressDetailsFromCallbackRITotalSpent'] = GetAddressDetailsFromCallbackRITotalSpent
globals()['GetAddressDetailsRIConfirmedBalance'] = GetAddressDetailsRIConfirmedBalance
from cryptoapis.model.get_address_details_from_callback_ri import GetAddressDetailsFromCallbackRI


class TestGetAddressDetailsFromCallbackRI(unittest.TestCase):
    """GetAddressDetailsFromCallbackRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetAddressDetailsFromCallbackRI(self):
        """Test GetAddressDetailsFromCallbackRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetAddressDetailsFromCallbackRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.decode_raw_transaction_hex_risd_vin_inner_script_sig import DecodeRawTransactionHexRISDVinInnerScriptSig
globals()['DecodeRawTransactionHexRISDVinInnerScriptSig'] = DecodeRawTransactionHexRISDVinInnerScriptSig
from cryptoapis.model.decode_raw_transaction_hex_risd_vin_inner import DecodeRawTransactionHexRISDVinInner


class TestDecodeRawTransactionHexRISDVinInner(unittest.TestCase):
    """DecodeRawTransactionHexRISDVinInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDecodeRawTransactionHexRISDVinInner(self):
        """Test DecodeRawTransactionHexRISDVinInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DecodeRawTransactionHexRISDVinInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_xrp_ripple_transactions_by_address_and_time_range_e401 import ListXRPRippleTransactionsByAddressAndTimeRangeE401
globals()['ListXRPRippleTransactionsByAddressAndTimeRangeE401'] = ListXRPRippleTransactionsByAddressAndTimeRangeE401
from cryptoapis.model.list_xrp_ripple_transactions_by_address_and_time_range401_response import ListXRPRippleTransactionsByAddressAndTimeRange401Response


class TestListXRPRippleTransactionsByAddressAndTimeRange401Response(unittest.TestCase):
    """ListXRPRippleTransactionsByAddressAndTimeRange401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByAddressAndTimeRange401Response(self):
        """Test ListXRPRippleTransactionsByAddressAndTimeRange401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByAddressAndTimeRange401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_last_mined_block_ribsb import GetLastMinedBlockRIBSB
from cryptoapis.model.get_last_mined_block_ribsbc import GetLastMinedBlockRIBSBC
from cryptoapis.model.get_last_mined_block_ribsbsc import GetLastMinedBlockRIBSBSC
from cryptoapis.model.get_last_mined_block_ribsd import GetLastMinedBlockRIBSD
from cryptoapis.model.get_last_mined_block_ribsd2 import GetLastMinedBlockRIBSD2
from cryptoapis.model.get_last_mined_block_ribse import GetLastMinedBlockRIBSE
from cryptoapis.model.get_last_mined_block_ribsec import GetLastMinedBlockRIBSEC
from cryptoapis.model.get_last_mined_block_ribsl import GetLastMinedBlockRIBSL
from cryptoapis.model.get_last_mined_block_ribsz import GetLastMinedBlockRIBSZ
globals()['GetLastMinedBlockRIBSB'] = GetLastMinedBlockRIBSB
globals()['GetLastMinedBlockRIBSBC'] = GetLastMinedBlockRIBSBC
globals()['GetLastMinedBlockRIBSBSC'] = GetLastMinedBlockRIBSBSC
globals()['GetLastMinedBlockRIBSD'] = GetLastMinedBlockRIBSD
globals()['GetLastMinedBlockRIBSD2'] = GetLastMinedBlockRIBSD2
globals()['GetLastMinedBlockRIBSE'] = GetLastMinedBlockRIBSE
globals()['GetLastMinedBlockRIBSEC'] = GetLastMinedBlockRIBSEC
globals()['GetLastMinedBlockRIBSL'] = GetLastMinedBlockRIBSL
globals()['GetLastMinedBlockRIBSZ'] = GetLastMinedBlockRIBSZ
from cryptoapis.model.get_last_mined_block_ribs import GetLastMinedBlockRIBS


class TestGetLastMinedBlockRIBS(unittest.TestCase):
    """GetLastMinedBlockRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetLastMinedBlockRIBS(self):
        """Test GetLastMinedBlockRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetLastMinedBlockRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from cryptoapis.exceptions import ApiAttributeError


def lazy_import():
    from cryptoapis.model.get_transaction_details_by_transaction_idribsbsc_gas_price import GetTransactionDetailsByTransactionIDRIBSBSCGasPrice
    from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
    from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
    from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsb import GetWalletTransactionDetailsByTransactionIDRIBSB
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc import GetWalletTransactionDetailsByTransactionIDRIBSBC
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbsc import GetWalletTransactionDetailsByTransactionIDRIBSBSC
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsd import GetWalletTransactionDetailsByTransactionIDRIBSD
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsd2 import GetWalletTransactionDetailsByTransactionIDRIBSD2
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribse import GetWalletTransactionDetailsByTransactionIDRIBSE
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsec import GetWalletTransactionDetailsByTransactionIDRIBSEC
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsl import GetWalletTransactionDetailsByTransactionIDRIBSL
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsz import GetWalletTransactionDetailsByTransactionIDRIBSZ
    from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsz_vin_inner import GetWalletTransactionDetailsByTransactionIDRIBSZVinInner
    from cryptoapis.model.list_transactions_by_block_height_ribsz_vout_inner import ListTransactionsByBlockHeightRIBSZVoutInner
    globals()['GetTransactionDetailsByTransactionIDRIBSBSCGasPrice'] = GetTransactionDetailsByTransactionIDRIBSBSCGasPrice
    globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
    globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
    globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSB'] = GetWalletTransactionDetailsByTransactionIDRIBSB
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSBC'] = GetWalletTransactionDetailsByTransactionIDRIBSBC
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSBSC'] = GetWalletTransactionDetailsByTransactionIDRIBSBSC
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSD'] = GetWalletTransactionDetailsByTransactionIDRIBSD
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSD2'] = GetWalletTransactionDetailsByTransactionIDRIBSD2
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSE'] = GetWalletTransactionDetailsByTransactionIDRIBSE
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSEC'] = GetWalletTransactionDetailsByTransactionIDRIBSEC
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSL'] = GetWalletTransactionDetailsByTransactionIDRIBSL
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSZ'] = GetWalletTransactionDetailsByTransactionIDRIBSZ
    globals()['GetWalletTransactionDetailsByTransactionIDRIBSZVinInner'] = GetWalletTransactionDetailsByTransactionIDRIBSZVinInner
    globals()['ListTransactionsByBlockHeightRIBSZVoutInner'] = ListTransactionsByBlockHeightRIBSZVoutInner


class GetWalletTransactionDetailsByTransactionIDRIBS(ModelComposed):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'v_join_split': ([GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner],),  # noqa: E501
            'v_shielded_output': ([GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner],),  # noqa: E501
            'v_shielded_spend': ([GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner],),  # noqa: E501
            'locktime': (int,),  # noqa: E501
            'size': (int,),  # noqa: E501
            'v_size': (int,),  # noqa: E501
            'version': (int,),  # noqa: E501
            'vin': ([GetWalletTransactionDetailsByTransactionIDRIBSZVinInner],),  # noqa: E501
            'vout': ([ListTransactionsByBlockHeightRIBSZVoutInner],),  # noqa: E501
            'contract': (str,),  # noqa: E501
            'gas_limit': (str,),  # noqa: E501
            'gas_price': (GetTransactionDetailsByTransactionIDRIBSBSCGasPrice,),  # noqa: E501
            'gas_used': (str,),  # noqa: E501
            'input_data': (str,),  # noqa: E501
            'nonce': (int,),  # noqa: E501
            'transaction_status': (str,),  # noqa: E501
            'binding_sig': (str,),  # noqa: E501
            'expiry_height': (int,),  # noqa: E501
            'join_split_pub_key': (str,),  # noqa: E501
            'join_split_sig': (str,),  # noqa: E501
            'overwintered': (bool,),  # noqa: E501
            'value_balance': (str,),  # noqa: E501
            'version_group_id': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'v_join_split': 'vJoinSplit',  # noqa: E501
        'v_shielded_output': 'vShieldedOutput',  # noqa: E501
        'v_shielded_spend': 'vShieldedSpend',  # noqa: E501
        'locktime': 'locktime',  # noqa: E501
        'size': 'size',  # noqa: E501
        'v_size': 'vSize',  # noqa: E501
        'version': 'version',  # noqa: E501
        'vin': 'vin',  # noqa: E501
        'vout': 'vout',  # noqa: E501
        'contract': 'contract',  # noqa: E501
        'gas_limit': 'gasLimit',  # noqa: E501
        'gas_price': 'gasPrice',  # noqa: E501
        'gas_used': 'gasUsed',  # noqa: E501
        'input_data': 'inputData',  # noqa: E501
        'nonce': 'nonce',  # noqa: E501
        'transaction_status': 'transactionStatus',  # noqa: E501
        'binding_sig': 'bindingSig',  # noqa: E501
        'expiry_height': 'expiryHeight',  # noqa: E501
        'join_split_pub_key': 'joinSplitPubKey',  # noqa: E501
        'join_split_sig': 'joinSplitSig',  # noqa: E501
        'overwintered': 'overwintered',  # noqa: E501
        'value_balance': 'valueBalance',  # noqa: E501
        'version_group_id': 'versionGroupId',  # noqa: E501
    }

    read_only_vars = {
    }

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """GetWalletTransactionDetailsByTransactionIDRIBS - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            v_join_split ([GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner]): Represents a sequence of JoinSplit descriptions using BCTV14 proofs.. [optional]  # noqa: E501
            v_shielded_output ([GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner]): Object Array representation of transaction output descriptions. [optional]  # noqa: E501
            v_shielded_spend ([GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner]): Object Array representation of transaction spend descriptions. [optional]  # noqa: E501
            locktime (int): Represents the time at which a particular transaction can be added to the blockchain.. [optional]  # noqa: E501
            size (int): Represents the total size of this transaction.. [optional]  # noqa: E501
            v_size (int): Represents the virtual size of this transaction.. [optional]  # noqa: E501
            version (int): Represents the transaction version number.. [optional]  # noqa: E501
            vin ([GetWalletTransactionDetailsByTransactionIDRIBSZVinInner]): Object Array representation of transaction inputs. [optional]  # noqa: E501
            vout ([ListTransactionsByBlockHeightRIBSZVoutInner]): Object Array representation of transaction outputs. [optional]  # noqa: E501
            contract (str): Represents the specific transaction contract. [optional]  # noqa: E501
            gas_limit (str): Represents the amount of gas used by this specific transaction alone.. [optional]  # noqa: E501
            gas_price (GetTransactionDetailsByTransactionIDRIBSBSCGasPrice): [optional]  # noqa: E501
            gas_used (str): Defines the unit of the gas price amount, e.g. BTC, ETH, XRP.. [optional]  # noqa: E501
            input_data (str): Represents additional information that is required for the transaction.. [optional]  # noqa: E501
            nonce (int): Represents the sequential running number for an address, starting from 0 for the first transaction. E.g., if the nonce of a transaction is 10, it would be the 11th transaction sent from the sender's address.. [optional]  # noqa: E501
            transaction_status (str): String representation of the transaction status. [optional]  # noqa: E501
            binding_sig (str): It is used to enforce balance of Spend and Output transfers, in order to prevent their replay across transactions.. [optional]  # noqa: E501
            expiry_height (int): Represents a block height after which the transaction will expire.. [optional]  # noqa: E501
            join_split_pub_key (str): Represents an encoding of a JoinSplitSig public validating key.. [optional]  # noqa: E501
            join_split_sig (str): Is used to sign transactions that contain at least one JoinSplit description.. [optional]  # noqa: E501
            overwintered (bool): \"Overwinter\" is the network upgrade for the Zcash blockchain.. [optional]  # noqa: E501
            value_balance (str): String representation of the transaction value balance. [optional]  # noqa: E501
            version_group_id (str): Represents the transaction version group ID.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)

        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
        '_composed_instances',
        '_var_name_to_model_instances',
        '_additional_properties_model_instances',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """GetWalletTransactionDetailsByTransactionIDRIBS - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            v_join_split ([GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner]): Represents a sequence of JoinSplit descriptions using BCTV14 proofs.. [optional]  # noqa: E501
            v_shielded_output ([GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner]): Object Array representation of transaction output descriptions. [optional]  # noqa: E501
            v_shielded_spend ([GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner]): Object Array representation of transaction spend descriptions. [optional]  # noqa: E501
            locktime (int): Represents the time at which a particular transaction can be added to the blockchain.. [optional]  # noqa: E501
            size (int): Represents the total size of this transaction.. [optional]  # noqa: E501
            v_size (int): Represents the virtual size of this transaction.. [optional]  # noqa: E501
            version (int): Represents the transaction version number.. [optional]  # noqa: E501
            vin ([GetWalletTransactionDetailsByTransactionIDRIBSZVinInner]): Object Array representation of transaction inputs. [optional]  # noqa: E501
            vout ([ListTransactionsByBlockHeightRIBSZVoutInner]): Object Array representation of transaction outputs. [optional]  # noqa: E501
            contract (str): Represents the specific transaction contract. [optional]  # noqa: E501
            gas_limit (str): Represents the amount of gas used by this specific transaction alone.. [optional]  # noqa: E501
            gas_price (GetTransactionDetailsByTransactionIDRIBSBSCGasPrice): [optional]  # noqa: E501
            gas_used (str): Defines the unit of the gas price amount, e.g. BTC, ETH, XRP.. [optional]  # noqa: E501
            input_data (str): Represents additional information that is required for the transaction.. [optional]  # noqa: E501
            nonce (int): Represents the sequential running number for an address, starting from 0 for the first transaction. E.g., if the nonce of a transaction is 10, it would be the 11th transaction sent from the sender's address.. [optional]  # noqa: E501
            transaction_status (str): String representation of the transaction status. [optional]  # noqa: E501
            binding_sig (str): It is used to enforce balance of Spend and Output transfers, in order to prevent their replay across transactions.. [optional]  # noqa: E501
            expiry_height (int): Represents a block height after which the transaction will expire.. [optional]  # noqa: E501
            join_split_pub_key (str): Represents an encoding of a JoinSplitSig public validating key.. [optional]  # noqa: E501
            join_split_sig (str): Is used to sign transactions that contain at least one JoinSplit description.. [optional]  # noqa: E501
            overwintered (bool): \"Overwinter\" is the network upgrade for the Zcash blockchain.. [optional]  # noqa: E501
            value_balance (str): String representation of the transaction value balance. [optional]  # noqa: E501
            version_group_id (str): Represents the transaction version group ID.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")

    @cached_property
    def _composed_schemas():
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        lazy_import()
        return {
          'anyOf': [
          ],
          'allOf': [
          ],
          'oneOf': [
              GetWalletTransactionDetailsByTransactionIDRIBSB,
              GetWalletTransactionDetailsByTransactionIDRIBSBC,
              GetWalletTransactionDetailsByTransactionIDRIBSBSC,
              GetWalletTransactionDetailsByTransactionIDRIBSD,
              GetWalletTransactionDetailsByTransactionIDRIBSD2,
              GetWalletTransactionDetailsByTransactionIDRIBSE,
              GetWalletTransactionDetailsByTransactionIDRIBSEC,
              GetWalletTransactionDetailsByTransactionIDRIBSL,
              GetWalletTransactionDetailsByTransactionIDRIBSZ,
          ],
        }
